==> mathjax_2.7.0.orig.tar.xz: MathJax-2.7.0/unpacked/localization/lt/MathMenu.js <==
/*************************************************************
 *
 *  MathJax/localization/lt/MathMenu.js
 *
 *  Copyright (c) 2009-2016 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("lt","MathMenu",{
        version: "2.7.0",
        isLoaded: true,
        strings: {
          Show: "Rodyti matematik\u0105 kaip",
          MathMLcode: "\u201EMathML\u201C kodas",
          OriginalMathML: "Pradinis \u201EMathML\u201C",
          TeXCommands: "\u201ETeX\u201C komandos",
          AsciiMathInput: "\u201EAsciiMathML\u201C \u012Fvestis",
          Original: "Pradin\u0117 forma",
          ErrorMessage: "Klaidos prane\u0161imas",
          Annotation: "Santrauka",
          TeX: "TeX",
          StarMath: "StarMath",
          Maple: "Maple",
          ContentMathML: "Content MathML",
          OpenMath: "OpenMath",
          texHints: "Rodyti \u201ETeX\u201C u\u017Euominas kalboje \u201EMathML\u201C",
          Settings: "Matematikos nuostatos",
          ZoomTrigger: "Mastelio jungiklis",
          Hover: "U\u017Evestis",
          Click: "Spustel\u0117ti",
          DoubleClick: "Du kartus spustel\u0117ti",
          NoZoom: "Nekeisti mastelio",
          TriggerRequires: "Jungiklis reikalauja:",
          Option: "Nuostata",
          Alt: "Alt",
          Command: "Komanda",
          Control: "Valdiklis",
          Shift: "Lyg 2",
          ZoomFactor: "Mastelio santykis",
          Renderer: "Matematikos vaizduotuvas",
          MPHandles: "Leisti \u201EMathPlayer\u201C vykdyti:",
          MenuEvents: "Meniu \u012Fvykiai",
          MouseEvents: "Pel\u0117s \u012Fvykiai",
          MenuAndMouse: "Pel\u0117s ir meniu \u012Fvykiai",
          FontPrefs: "\u0160rift\u0173 nuostatos",
          ForHTMLCSS: "Skirta HTML-CSS:",
          Auto: "Savaime",
          TeXLocal: "TeX (vietinis)",
          TeXWeb: "TeX (tinklas)",
          TeXImage: "TeX (paveiksl\u0117lis)",
          STIXLocal: "STIX (vietinis)",
          STIXWeb: "STIX (tinklas)",
          AsanaMathWeb: "Asana Math (tinklas)",
          GyrePagellaWeb: "Gyre Pagella (tinklas)",
          GyreTermesWeb: "Gyre Termes (tinklas)",
          LatinModernWeb: "Latin Modern (tinklas)",
          NeoEulerWeb: "Neo Euler (tinklas)",
          ContextMenu: "Kontekstinis meniu",
          Browser: "Nar\u0161ykl\u0117",
          Scale: "Keisti matematikos mastel\u012F ...",
          Discoverable: "Ry\u0161kinti u\u017Evedus",
          Locale: "Kalba",
          LoadLocale: "\u012Ekelti i\u0161 URL ...",
          About: "Apie \u201EMathJax\u201C",
          Help: "\u201EMathJax\u201C \u017Einynas",
          localTeXfonts: "vartojami vietiniai \u201ETeX\u201C \u0161riftai",
          webTeXfonts: "vartojamas tinklinis \u201ETeX\u201C \u0161riftas",
          imagefonts: "vartojami paveiksliniai \u0161riftai",
          localSTIXfonts: "vartojami vietiniai \u201ESTIX\u201C \u0161riftai",
          webSVGfonts: "vartojami tinkliniai SVG \u0161riftai",
          genericfonts: "vartojami bendrieji unikodo \u0161riftai",
          wofforotffonts: "WOFF arba OTF \u0161riftai",
          eotffonts: "EOT \u0161riftai",
          svgfonts: "SVG \u0161riftai",
          WebkitNativeMMLWarning: "Tik\u0117tina, kad j\u016Bs\u0173 nar\u0161ykl\u0117je \u201EMathML\u201C vartojimas nenumatytas, tod\u0117l i\u0161vest\u012F perjungus \u012F \u201EMathML\u201C, tinklalapyje galima i\u0161darkyti matematikos \u017Eenklus.",
          MSIENativeMMLWarning: "Norint \u201EMathML\u201C i\u0161vest\u012F apdoroti nar\u0161ykl\u0117je \u201EInternet Explorer\u201C, b\u016Btinas papildinys \u201EMathPlayer\u201C.",
          OperaNativeMMLWarning: "Nar\u0161ykl\u0117je \u201EOpera\u201C \u201EMathML\u201C vartojimas yra ribotas, tod\u0117l i\u0161vest\u012F perjungus \u012F \u201EMathML\u201C kai kurie rei\u0161kiniai gali b\u016Bti vaizduojami nekokybi\u0161kai.",
          SafariNativeMMLWarning: "J\u016Bs\u0173 nar\u0161ykl\u0117s vidinis \u201EMathML\u201C nenumato vis\u0173 \u201EMathJax\u201C ypatybi\u0173, tod\u0117l kai kurie rei\u0161kiniai gali b\u016Bti vaizduojami nekokybi\u0161kai.",
          FirefoxNativeMMLWarning: "J\u016Bs\u0173 nar\u0161ykl\u0117s vidinis \u201EMathML\u201C nenumato vis\u0173 \u201EMathJax\u201C ypatybi\u0173, tod\u0117l kai kurie rei\u0161kiniai gali b\u016Bti vaizduojami nekokybi\u0161kai.",
          MSIESVGWarning: "SVG nar\u0161ykl\u0117je \u201EInternet Explorer\u201C diegiama tik nuo IE9 laidos. IE8 ir ankstesn\u0117se laidose ji galima tik emuliuojant. I\u0161vest\u012F perjungus \u012F SVG, matematikos \u017Eenklai vaizduojami nekokybi\u0161kai.",
          LoadURL: "Vertimo duomenis \u012Fkelti i\u0161 \u0161io URL:",
          BadURL: "URL adresas turi b\u016Bti skirtas \u201EJavaScript\u201C bylai, apibr\u0117\u017Eian\u010Diai \u201EMathJax\u201C vertimo duomenis. \u201EJavaScript\u201C bylos prievardis turi b\u016Bti \u201E.js\u201C.",
          BadData: "Vertimo duomen\u0173 i\u0161 %1 \u012Fkelti nepavyko.",
          SwitchAnyway: "Ar vis tiek perjungti vaizduotuv\u0105?\n\n(Paspaudus \u201EVykdyti\u201C, vaizduotuvas perjungiamas; paspaudus \u201ENutraukti\u201C, lieka veikti esamas vaizduotuvas.)",
          ScaleMath: "Keisti matematikos mastel\u012F (supan\u010Dio teksto at\u017Evilgiu) santykiu:",
          NonZeroScale: "Mastelio reik\u0161m\u0117 negali b\u016Bti 0",
          PercentScale: "Mastelis \u017Eymimas procentais (pavyzd\u017Eiui, 120%%)",
          IE8warning: "Ar tikrai keisti \u201EMathPlayer\u201C nuostatas?",
          IE9warning: "I\u0161jungus kontekstin\u012F \u201EMathJax\u201C meniu, \u201EMathJax\u201C meniu atver\u010Diamas nuspaudus Alt ir spustel\u0117jus rei\u0161kin\u012F.",
          NoOriginalForm: "Pradin\u0117s formos n\u0117ra",
          Close: "U\u017Edaryti",
          EqSource: "\u201EMathJax\u201C lygties \u0161altinis"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/lt/MathMenu.js");

==> mathjax_2.7.3+dfsg.orig.tar.xz: MathJax-2.7.3/unpacked/localization/lt/MathMenu.js <==
/*************************************************************
 *
 *  MathJax/localization/lt/MathMenu.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("lt","MathMenu",{
        version: "2.7.3",
        isLoaded: true,
        strings: {
          Show: "Rodyti",
          MathMLcode: "\u201EMathML\u201C tekst\u0105",
          OriginalMathML: "Pradinis \u201EMathML\u201C",
          TeXCommands: "\u201ETeX\u201C komandas",
          AsciiMathInput: "\u201EAsciiMathML\u201C \u012Fvestis",
          Original: "Pradin\u0117 forma",
          ErrorMessage: "Klaidos prane\u0161imas",
          Annotation: "santrauk\u0105",
          TeX: "TeX",
          StarMath: "StarMath",
          Maple: "Maple",
          ContentMathML: "Content MathML",
          OpenMath: "OpenMath",
          texHints: "\u201ETeX\u201C u\u017Euominas \u201EMathML\u201C kalba",
          Settings: "Nustatyti",
          ZoomTrigger: "mastelio jungikl\u012F",
          Hover: "u\u017Evedus",
          Click: "spustel\u0117jus",
          DoubleClick: "dukart spustel\u0117jus",
          NoZoom: "Nekeisti",
          TriggerRequires: "Kei\u010Diant spaud\u017Eiama:",
          Option: "Nuostata",
          Alt: "Alt",
          Command: "Komanda",
          Control: "Vald",
          Shift: "Lyg 2",
          ZoomFactor: "mastelio daugikl\u012F",
          Renderer: "teikikl\u012F",
          MPHandles: "Leisti \u201EMathPlayer\u201C vykdyti:",
          MenuEvents: "Meniu \u012Fvykiai",
          MouseEvents: "Pel\u0117s \u012Fvykiai",
          MenuAndMouse: "Pel\u0117s ir meniu \u012Fvykiai",
          FontPrefs: "\u0160rift\u0173 nuostatos",
          ForHTMLCSS: "Skirta HTML-CSS:",
          Auto: "Savaime",
          TeXLocal: "TeX (vietinis)",
          TeXWeb: "TeX (tinklas)",
          TeXImage: "TeX (paveiksl\u0117lis)",
          STIXLocal: "STIX (vietinis)",
          STIXWeb: "STIX (tinklas)",
          AsanaMathWeb: "Asana Math (tinklas)",
          GyrePagellaWeb: "Gyre Pagella (tinklas)",
          GyreTermesWeb: "Gyre Termes (tinklas)",
          LatinModernWeb: "Latin Modern (tinklas)",
          NeoEulerWeb: "Neo Euler (tinklas)",
          ContextMenu: "Kontekstinis meniu",
          Browser: "Nar\u0161ykl\u0117",
          Scale: "bendr\u0105 mastel\u012F\u2026",
          Discoverable: "Ry\u0161kinti u\u017Evedus",
          Locale: "Kalba",
          LoadLocale: "\u012Ekelti i\u0161 URL ...",
          About: "Apie \u201EMathJax\u201C",
          Help: "\u017Dinynas",
          localTeXfonts: "vartojami vietiniai \u201ETeX\u201C \u0161riftai",
          webTeXfonts: "Taikomas tinklinis \u201ETeX\u201C \u0161riftas",
          imagefonts: "vartojami paveiksliniai \u0161riftai",
          localSTIXfonts: "vartojami vietiniai \u201ESTIX\u201C \u0161riftai",
          webSVGfonts: "vartojami tinkliniai SVG \u0161riftai",
          genericfonts: "vartojami bendrieji unikodo \u0161riftai",
          wofforotffonts: "WOFF arba OTF \u0161riftai",
          eotffonts: "EOT \u0161riftai",
          svgfonts: "SVG \u0161riftai",
          WebkitNativeMMLWarning: "Tik\u0117tina, kad j\u016Bs\u0173 nar\u0161ykl\u0117je \u201EMathML\u201C vartojimas nenumatytas, tod\u0117l i\u0161vest\u012F perjungus \u012F \u201EMathML\u201C, tinklalapyje galima i\u0161darkyti matematikos \u017Eenklus.",
          MSIENativeMMLWarning: "Norint \u201EMathML\u201C i\u0161vest\u012F apdoroti nar\u0161ykl\u0117je \u201EInternet Explorer\u201C, b\u016Btinas papildinys \u201EMathPlayer\u201C.",
          OperaNativeMMLWarning: "Nar\u0161ykl\u0117je \u201EOpera\u201C \u201EMathML\u201C vartojimas yra ribotas, tod\u0117l i\u0161vest\u012F perjungus \u012F \u201EMathML\u201C kai kurie rei\u0161kiniai gali b\u016Bti vaizduojami nekokybi\u0161kai.",
          SafariNativeMMLWarning: "J\u016Bs\u0173 nar\u0161ykl\u0117s \u201EMathML\u201C sande ne\u012Fdiegtos visos \u201EMathJax\u201C ypatyb\u0117s, tod\u0117l kai kurie rei\u0161kiniai gali b\u016Bti vaizduojami nekokybi\u0161kai.",
          FirefoxNativeMMLWarning: "J\u016Bs\u0173 nar\u0161ykl\u0117s \u201EMathML\u201C sande ne\u012Fdiegtos visos \u201EMathJax\u201C ypatyb\u0117s, tod\u0117l kai kurie rei\u0161kiniai gali b\u016Bti vaizduojami nekokybi\u0161kai.",
          MSIESVGWarning: "SVG nar\u0161ykl\u0117je \u201EInternet Explorer\u201C diegiama tik nuo IE9 laidos. IE8 ir ankstesn\u0117se laidose ji galima tik emuliuojant. I\u0161vest\u012F perjungus \u012F SVG, matematikos \u017Eenklai vaizduojami nekokybi\u0161kai.",
          LoadURL: "Vertimo duomenis \u012Fkelti i\u0161 \u0161io URL:",
          BadURL: "URL adresas turi b\u016Bti skirtas \u201EJavaScript\u201C bylai, apibr\u0117\u017Eian\u010Diai \u201EMathJax\u201C vertimo duomenis. \u201EJavaScript\u201C bylos prievardis turi b\u016Bti \u201E.js\u201C.",
          BadData: "Vertimo duomen\u0173 i\u0161 %1 \u012Fkelti nepavyko.",
          SwitchAnyway: "Ar vis tiek keisti vaizdavimo b\u016Bd\u0105?\n\n(Vaizdavimo b\u016Bdas kei\u010Diamas, spaud\u017Eiant \u201EVykdyti\u201C; paliekamas tas pats, spaud\u017Eiant \u201ENutraukti\u201C.)",
          ScaleMath: "Bendrasis mastelis aplinkinio teksto at\u017Evilgiu:",
          NonZeroScale: "Mastelio reik\u0161m\u0117 negali b\u016Bti 0",
          PercentScale: "Mastelis \u017Eymimas procentais (pavyzd\u017Eiui, 120%%)",
          IE8warning: "Ar tikrai keisti \u201EMathPlayer\u201C nuostatas?",
          IE9warning: "I\u0161jungus kontekstin\u012F \u201EMathJax\u201C meniu, \u201EMathJax\u201C meniu atver\u010Diamas nuspaudus Alt ir spustel\u0117jus rei\u0161kin\u012F.",
          NoOriginalForm: "Pradin\u0117s formos n\u0117ra",
          Close: "U\u017Edaryti",
          EqSource: "\u201EMathJax\u201C lygties \u0161altinis",
          CloseAboutDialog: "Nutraukti dialog\u0105 apie \u201EMathJax\u201C",
          FastPreview: "Spar\u010Dioji per\u017Ei\u016Bra",
          AssistiveMML: "Pagalbinis \u201EMathML\u201C",
          InTabOrder: "\u012Etraukti \u012F \u0105seli\u0173 eil\u0119"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/lt/MathMenu.js");
